Index: modules/node/node.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/node/node.module,v
retrieving revision 1.1092
diff -u -p -r1.1092 node.module
--- modules/node/node.module	5 Aug 2009 15:58:34 -0000	1.1092
+++ modules/node/node.module	6 Aug 2009 03:33:39 -0000
@@ -1225,11 +1225,11 @@ function template_preprocess_node(&$vari
   // Display post information only on certain node types.
   if (variable_get('node_submitted_' . $node->type, TRUE)) {
     $variables['submitted'] = theme('node_submitted', $node);
-    $variables['picture'] = theme_get_setting('toggle_node_user_picture') ? theme('user_picture', $node) : '';
+    $variables['user_picture'] = theme_get_setting('toggle_node_user_picture') ? theme('user_picture', $node) : '';
   }
   else {
     $variables['submitted'] = '';
-    $variables['picture'] = '';
+    $variables['user_picture'] = '';
   }
 
   // Gather node classes.
Index: modules/node/node.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/node/node.tpl.php,v
retrieving revision 1.18
diff -u -p -r1.18 node.tpl.php
--- modules/node/node.tpl.php	23 Jul 2009 22:12:53 -0000	1.18
+++ modules/node/node.tpl.php	6 Aug 2009 03:33:39 -0000
@@ -11,8 +11,7 @@
  *   print a subset such as render($content['field_example']). Use
  *   hide($content['field_example']) to temporarily suppress the printing of a
  *   given element.
- * - $picture: The authors picture of the node output from
- *   theme_user_picture().
+ * - $user_picture: The node author's picture from user-picture.tpl.php.
  * - $date: Formatted creation date (use $created to reformat with
  *   format_date()).
  * - $name: Themed username of node author output from theme_username().
@@ -65,23 +64,25 @@
  * @see template_process()
  */
 ?>
-<div id="node-<?php print $node->nid; ?>" class="<?php print $classes ?> clearfix">
+<div id="node-<?php print $node->nid; ?>" class="<?php print $classes; ?> clearfix">
 
-<?php print $picture ?>
+  <?php print $user_picture; ?>
 
-<?php if (!$page): ?>
-  <h2><a href="<?php print $node_url ?>"><?php print $title ?></a></h2>
-<?php endif; ?>
-
-  <div class="meta">
-  <?php if ($submitted): ?>
-    <span class="submitted"><?php print $submitted ?></span>
+  <?php if (!$page): ?>
+    <h2><a href="<?php print $node_url; ?>"><?php print $title; ?></a></h2>
   <?php endif; ?>
 
-  <?php if (!empty($content['links']['terms'])): ?>
-    <div class="terms terms-inline"><?php render($content['links']['terms']) ?></div>
-  <?php endif;?>
-  </div>
+  <?php if ($submitted || !empty($content['links']['terms'])): ?>
+    <div class="meta">
+      <?php if ($submitted): ?>
+        <span class="submitted"><?php print $submitted; ?></span>
+      <?php endif; ?>
+
+      <?php if (!empty($content['links']['terms'])): ?>
+        <div class="terms terms-inline"><?php print render($content['links']['terms']); ?></div>
+      <?php endif; ?>
+    </div>
+  <?php endif; ?>
 
   <div class="content">
     <?php
Index: modules/profile/profile.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/profile/profile.module,v
retrieving revision 1.264
diff -u -p -r1.264 profile.module
--- modules/profile/profile.module	2 Aug 2009 15:44:08 -0000	1.264
+++ modules/profile/profile.module	6 Aug 2009 03:33:39 -0000
@@ -533,7 +533,7 @@ function profile_category_access($accoun
  */
 function template_preprocess_profile_block(&$variables) {
 
-  $variables['picture'] = theme('user_picture', $variables['account']);
+  $variables['user_picture'] = theme('user_picture', $variables['account']);
   $variables['profile'] = array();
   // Supply filtered version of $fields that have values.
   foreach ($variables['fields'] as $field) {
@@ -557,7 +557,7 @@ function template_preprocess_profile_blo
  */
 function template_preprocess_profile_listing(&$variables) {
 
-  $variables['picture'] = theme('user_picture', $variables['account']);
+  $variables['user_picture'] = theme('user_picture', $variables['account']);
   $variables['name'] = theme('username', $variables['account']);
   $variables['profile'] = array();
   // Supply filtered version of $fields that have values.
Index: modules/user/user-rtl.css
===================================================================
RCS file: /cvs/drupal/drupal/modules/user/user-rtl.css,v
retrieving revision 1.4
diff -u -p -r1.4 user-rtl.css
--- modules/user/user-rtl.css	8 Apr 2008 22:50:55 -0000	1.4
+++ modules/user/user-rtl.css	6 Aug 2009 03:33:39 -0000
@@ -11,7 +11,7 @@
   clear: left;
 }
 
-.profile .picture {
+.profile .user-picture {
   float: left;
   margin: 0 0 1em 1em;
 }
Index: modules/user/user.css
===================================================================
RCS file: /cvs/drupal/drupal/modules/user/user.css,v
retrieving revision 1.12
diff -u -p -r1.12 user.css
--- modules/user/user.css	4 Aug 2009 03:27:11 -0000	1.12
+++ modules/user/user.css	6 Aug 2009 03:33:39 -0000
@@ -34,7 +34,7 @@
   clear: both;
   margin: 1em 0;
 }
-.profile .picture {
+.profile .user-picture {
   float: right; /* LTR */
   margin: 0 1em 1em 0; /* LTR */
 }
Index: modules/user/user.module
===================================================================
RCS file: /cvs/drupal/drupal/modules/user/user.module,v
retrieving revision 1.1017
diff -u -p -r1.1017 user.module
--- modules/user/user.module	4 Aug 2009 06:38:57 -0000	1.1017
+++ modules/user/user.module	6 Aug 2009 03:33:40 -0000
@@ -1153,7 +1153,7 @@ function user_block_view($delta = '') {
  * @see user-picture.tpl.php
  */
 function template_preprocess_user_picture(&$variables) {
-  $variables['picture'] = '';
+  $variables['user_picture'] = '';
   if (variable_get('user_pictures', 0)) {
     $account = $variables['account'];
     if (!empty($account->picture)) {
@@ -1177,14 +1177,14 @@ function template_preprocess_user_pictur
     if (isset($filepath)) {
       $alt = t("@user's picture", array('@user' => $account->name ? $account->name : variable_get('anonymous', t('Anonymous'))));
       if (module_exists('image') && $style = variable_get('user_picture_style', '')) {
-        $variables['picture'] = theme('image_style', $style, $filepath, $alt, $alt, array(), FALSE);
+        $variables['user_picture'] = theme('image_style', $style, $filepath, $alt, $alt, array(), FALSE);
       }
       else {
-        $variables['picture'] = theme('image', $filepath, $alt, $alt, array(), FALSE);
+        $variables['user_picture'] = theme('image', $filepath, $alt, $alt, array(), FALSE);
       }
       if (!empty($account->uid) && user_access('access user profiles')) {
         $attributes = array('attributes' => array('title' => t('View user profile.')), 'html' => TRUE);
-        $variables['picture'] = l($variables['picture'], "user/$account->uid", $attributes);
+        $variables['user_picture'] = l($variables['user_picture'], "user/$account->uid", $attributes);
       }
     }
   }
Index: themes/garland/node.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/node.tpl.php,v
retrieving revision 1.13
diff -u -p -r1.13 node.tpl.php
--- themes/garland/node.tpl.php	14 Jul 2009 10:29:10 -0000	1.13
+++ themes/garland/node.tpl.php	6 Aug 2009 03:33:40 -0000
@@ -1,34 +1,39 @@
 <?php
 // $Id: node.tpl.php,v 1.13 2009/07/14 10:29:10 dries Exp $
 ?>
-<div id="node-<?php print $node->nid; ?>" class="<?php print $classes ?>">
+<div id="node-<?php print $node->nid; ?>" class="<?php print $classes; ?>">
 
-<?php print $picture ?>
-<?php if ($page == 0): ?>
-  <h2><a href="<?php print $node_url ?>"><?php print $title ?></a></h2>
-<?php endif; ?>
+  <?php print $user_picture; ?>
+
+  <?php if (!$page): ?>
+    <h2><a href="<?php print $node_url; ?>"><?php print $title; ?></a></h2>
+  <?php endif; ?>
 
   <?php if ($submitted): ?>
     <span class="submitted"><?php print $submitted; ?></span>
   <?php endif; ?>
 
   <div class="content clearfix">
-    <?php hide($content['links']); hide($content['comments']); print render($content); ?>
+    <?php
+      // We hide the comments and links now so that we can render them later.
+      hide($content['comments']);
+      hide($content['links']);
+      print render($content);
+    ?>
   </div>
 
   <div class="clearfix">
-    <div class="meta">
     <?php if (!empty($content['links']['terms'])): ?>
-      <div class="terms"><?php print render($content['links']['terms']) ?></div>
-    <?php endif;?>
-    </div>
+      <div class="meta">
+        <div class="terms"><?php print render($content['links']['terms']); ?></div>
+      </div>
+    <?php endif; ?>
 
     <?php if (!empty($content['links'])): ?>
-      <div class="links"><?php print render($content['links']) ?></div>
+      <div class="links"><?php print render($content['links']); ?></div>
     <?php endif; ?>
 
     <?php print render($content['comments']); ?>
-
   </div>
 
 </div>
Index: themes/garland/style-rtl.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/style-rtl.css,v
retrieving revision 1.14
diff -u -p -r1.14 style-rtl.css
--- themes/garland/style-rtl.css	3 Aug 2009 03:04:34 -0000	1.14
+++ themes/garland/style-rtl.css	6 Aug 2009 03:33:40 -0000
@@ -206,7 +206,8 @@ ul.links li, ul.inline li {
   padding-left: 0;
 }
 
-.picture, .comment .submitted {
+.user-picture,
+.comment .submitted {
   padding-left: 0;
   float: left;
   clear: left;
Index: themes/garland/style.css
===================================================================
RCS file: /cvs/drupal/drupal/themes/garland/style.css,v
retrieving revision 1.61
diff -u -p -r1.61 style.css
--- themes/garland/style.css	4 Aug 2009 06:56:30 -0000	1.61
+++ themes/garland/style.css	6 Aug 2009 03:33:40 -0000
@@ -674,7 +674,8 @@ ul.links li, ul.inline li {
   padding-left: 1em;
 }
 
-.picture, .comment .submitted {
+.user-picture,
+.comment .submitted {
   float: right; /* LTR */
   clear: right; /* LTR */
   padding-left: 1em; /* LTR */

Index: modules/profile/profile-block.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/profile/profile-block.tpl.php,v
retrieving revision 1.3
diff -u -p -r1.3 profile-block.tpl.php
--- modules/profile/profile-block.tpl.php	13 Oct 2008 12:31:42 -0000	1.3
+++ modules/profile/profile-block.tpl.php	6 Aug 2009 03:33:39 -0000
@@ -7,7 +7,7 @@
  * block. It only shows in relation to a node displayed as a full page.
  *
  * Available variables:
  * - $picture: Image configured for the account linking to the users page.
  * - $profile: Keyed array of all profile fields that have a value.
  *
  * Each $field in $profile contains:
@@ -30,7 +30,7 @@
  * @see template_preprocess_profile_block()
  */
 ?>
-<?php print $picture; ?>
+<?php print $user_picture; ?>
 
 <?php foreach ($profile as $field) : ?>
   <p>
@@ -7,7 +7,7 @@
  *
  * Available variables:
- * - $picture: Image configured for the account linking to the users page.
+ * - $user_picture: Image configured for the account linking to the users page.
  * - $profile: Keyed array of all profile fields that have a value.
  *
Index: modules/profile/profile-listing.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/profile/profile-listing.tpl.php,v
retrieving revision 1.6
diff -u -p -r1.6 profile-listing.tpl.php
--- modules/profile/profile-listing.tpl.php	7 May 2009 10:39:38 -0000	1.6
+++ modules/profile/profile-listing.tpl.php	6 Aug 2009 03:33:39 -0000
@@ -11,7 +11,7 @@
  *
  * Available variables:
  * - $account: User's account object.
  * - $picture: Image configured for the account linking to the users page.
  * - $name: User's account name linking to the users page.
  * - $profile: Keyed array of all profile fields that are set as visible
  *   in member list pages (configured by site administrators). It also needs
@@ -38,7 +38,7 @@
  */
 ?>
 <div class="profile clearfix">
-  <?php print $picture; ?>
+  <?php print $user_picture; ?>
 
   <div class="name">
     <?php print $name; ?>
@@ -11,7 +11,7 @@
  * Available variables:
  * - $account: User's account object.
- * - $picture: Image configured for the account linking to the users page.
+ * - $user_picture: Image configured for the account linking to the users page.
  * - $name: User's account name linking to the users page.
  * - $profile: Keyed array of all profile fields that are set as visible
Index: modules/user/user-picture.tpl.php
===================================================================
RCS file: /cvs/drupal/drupal/modules/user/user-picture.tpl.php,v
retrieving revision 1.4
diff -u -p -r1.4 user-picture.tpl.php
--- modules/user/user-picture.tpl.php	24 Apr 2009 09:03:21 -0000	1.4
+++ modules/user/user-picture.tpl.php	6 Aug 2009 03:33:39 -0000
@@ -7,7 +7,7 @@
  * user's account.
  *
  * Available variables:
  * - $picture: Image set by the user or the site's default. Will be linked
  *   depending on the viewer's permission to view the users profile page.
  * - $account: Array of account information. Potentially unsafe. Be sure to
  *   check_plain() before use.
@@ -15,8 +15,8 @@
  * @see template_preprocess_user_picture()
  */
 ?>
-<?php if ($picture): ?>
-  <div class="picture">
-    <?php print $picture; ?>
+<?php if ($user_picture): ?>
+  <div class="user-picture">
+    <?php print $user_picture; ?>
   </div>
 <?php endif; ?>
@@ -7,7 +7,7 @@
  *
  * Available variables:
- * - $picture: Image set by the user or the site's default. Will be linked
+ * - $user_picture: Image set by the user or the site's default. Will be linked
  *   depending on the viewer's permission to view the users profile page.
  * - $account: Array of account information. Potentially unsafe. Be sure to